Learn R Programming

politeness (version 0.8.7)

textcounter: Text Counter

Description

Counts total prevalence of a set of items in each of a set of texts.

Usage

textcounter(
  counted,
  texts,
  words = FALSE,
  fixed = TRUE,
  num_mc_cores = parallel::detectCores()
)

Value

numeric vector as long as texts indicating total frequencies of counted items.

Arguments

counted

character vector of items to search for in the texts.

texts

character vector of to-be-searched text.

words

logical. Default FALSE. Does counted contain words, or sequences of chracters?

fixed

logical. Default TRUE. Use literal characters instead of regular expressions?

num_mc_cores

integer Number of cores for parallelization. Default is parallel::detectCores().