Counts total prevalence of a set of items in each of a set of texts.
textcounter(counted, texts, words = FALSE, fixed = TRUE,
num_mc_cores = parallel::detectCores())character vector of items to search for in the texts.
character vector of to-be-searched text.
logical. Default FALSE. Does counted contain words, or sequences of chracters?
logical. Default TRUE. Use literal characters instead of regular expressions?
integer Number of cores for parallelization. Default is parallel::detectCores().
numeric vector as long as texts indicating total frequencies of counted items.